==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/reflect/net/NetMethod.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.reflect.net
{
	public class NetMethod : com.db4o.reflect.ReflectMethod
	{
		private readonly j4o.lang.reflect.Method method;

		private readonly com.db4o.reflect.Reflector _reflector;

		public NetMethod(com.db4o.reflect.Reflector reflector, j4o.lang.reflect.Method method)
		{
			_reflector = reflector;
			this.method = method;
		}

		public com.db4o.reflect.ReflectClass getReturnType() 
		{
			return _reflector.forClass(method.getReturnType());
		}

		public virtual object invoke(object onObject, object[] parameters)
		{
			try
			{
				return method.invoke(onObject, parameters);
			}
			catch (System.Exception e)
			{
				return null;
			}
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/reflect/net/NetMethod.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.reflect.net
{
	public class NetMethod : com.db4o.reflect.ReflectMethod
	{
		private readonly j4o.lang.reflect.Method method;

		private readonly com.db4o.reflect.Reflector _reflector;

		public NetMethod(com.db4o.reflect.Reflector reflector, j4o.lang.reflect.Method method)
		{
			_reflector = reflector;
			this.method = method;
		}

		public com.db4o.reflect.ReflectClass GetReturnType() 
		{
			return _reflector.ForClass(method.GetReturnType());
		}

		public virtual object Invoke(object onObject, object[] parameters)
		{
			try
			{
				return method.Invoke(onObject, parameters);
			}
			catch (System.Exception e)
			{
				return null;
			}
		}
	}
}
